Module binlog

Module binlog 

MySQL binary log file parsing.

Provides structures and functions for reading MySQL binary log files, including the file header, format description event, and row-based events.

Binary logs use LittleEndian byte order (unlike InnoDB which uses BigEndian).

Re-exports

pub use checksum::validate_event_checksum;
pub use correlate::correlate_events;
pub use correlate::CorrelatedEvent;
pub use correlate::RowEventType;
pub use event::BinlogEvent;
pub use event::BinlogEventType;
pub use event::CommonEventHeader;
pub use events::analyze_binlog;
pub use events::BinlogAnalysis;
pub use events::BinlogEventSummary;
pub use events::RowsEvent;
pub use events::TableMapEvent;
pub use file::BinlogFile;
pub use header::FormatDescriptionEvent;
pub use header::RotateEvent;
pub use row_image::extract_pk_from_row_image;
pub use row_image::parse_column_metadata;
pub use row_image::BinlogColumnMeta;
pub use row_image::BinlogPkValue;

Modules

checksum
Binlog event CRC-32 checksum validation.
constants
MySQL binary log format constants.
correlate
Binlog-to-tablespace page correlation.
event
Binlog event types and common event header.
events
Binlog row-based event parsing and analysis.
file
Binlog file reader with event iteration.
header
Binary log file header and format description event parsing.
row_image
Binlog row image parsing — extract PK values from row event data.