execute

Function execute 

pub fn execute(
    opts: &FindOptions,
    writer: &mut dyn Write,
) -> Result<(), IdbError>
Search a MySQL data directory for pages matching a given page number, or scan for pages with checksum mismatches (--corrupt).