Module undo

Module undo 

CLI implementation for the inno undo subcommand.

Analyzes undo tablespace files (.ibu and .ibd) by reading rollback segment arrays, rollback segment headers, undo segment headers, and undo log header chains to produce a comprehensive transaction history and segment state report.

Structs

UndoOptions
Options for the inno undo subcommand.

Functions

execute
Analyze undo tablespace and display results.