pub struct RsegArrayHeader {
pub size: u32,
}Expand description
Rollback segment array page header (page type FIL_PAGE_RSEG_ARRAY, MySQL 8.0+).
This page is the first page of an undo tablespace (.ibu) and contains an array of rollback segment page numbers.
Fields
size: u32Number of rollback segment slots.
Implementations