pub struct UndoPageHeader {
pub page_type: UndoPageType,
pub start: u16,
pub free: u16,
}Expand description
Parsed undo log page header.
Fields
page_type: UndoPageTypeType of undo log (INSERT or UPDATE).
start: u16Offset of the start of undo log records on this page.
free: u16Offset of the first free byte on this page.
Implementations
Sourceimpl UndoPageHeader
impl UndoPageHeader
Sourcepub fn parse(page_data: &[u8]) -> Option<Self>
pub fn parse(page_data: &[u8]) -> Option<Self>
Parse an undo page header from a full page buffer.
The undo page header starts at FIL_PAGE_DATA (byte 38).
Examples
use idb::innodb::undo::{UndoPageHeader, UndoPageType};
use byteorder::{BigEndian, ByteOrder};
// Build a minimal page buffer (at least 38 + 18 = 56 bytes).
let mut page = vec![0u8; 64];
let base = 38; // FIL_PAGE_DATA
// Undo page type = UPDATE (2) at offset base+0
BigEndian::write_u16(&mut page[base..], 2);
// Start offset at base+2
BigEndian::write_u16(&mut page[base + 2..], 80);
// Free offset at base+4
BigEndian::write_u16(&mut page[base + 4..], 160);
let hdr = UndoPageHeader::parse(&page).unwrap();
assert_eq!(hdr.page_type, UndoPageType::Update);
assert_eq!(hdr.start, 80);
assert_eq!(hdr.free, 160);Trait Implementations
Sourceimpl Clone for UndoPageHeader
impl Clone for UndoPageHeader
Sourcefn clone(&self) -> UndoPageHeader
fn clone(&self) -> UndoPageHeader
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UndoPageHeader
impl Debug for UndoPageHeader