pub struct UndoRecord {
pub offset: usize,
pub record_type: UndoRecordType,
pub info_bits: u8,
pub next_offset: u16,
pub data_len: usize,
}Expand description
A parsed undo record within an undo log page.
Fields
offset: usizeByte offset of this record within the page.
record_type: UndoRecordTypeOperation type.
info_bits: u8Info bits (compilation info flags from upper bits of type byte).
next_offset: u16Offset of the next undo record (2-byte pointer), 0 if last.
data_len: usizeApproximate data length of this record (bytes until next record or free pointer).